"""Utils for ChatBot"""
from __future__ import annotations

from typing import List

EXIT_INPUTS: List[str] = ["bye", "sayonara", "exit", "shutdown", "stop", "close"]
HELLO_INPUTS: List[str] = [
    "hello",
    "hi",
    "hello world",
    "hello chatbot",
    "hello bot",
    "hello",
    "hey",
]
WELCOME_MSG: str = (
    "\n🙏 Welcome to Unoffical ChatGpt Bot 🤖.\n🕵️  I am here to help humanity.\nℹ️  Please ask me anything.\n"
    + "\n🙏 Since I am new, I am learning as much as possible. So, Please co-operate with me."
    + "\n😎 I can Auto complete text, Q&A, Grammer correction, Write code, Language translations, NLP and many more stuffs. Try me !!!\n"
)
